From c7891b833f9cd13b0bccd4113e2c290e4af8e107 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Allan=20Nordh=C3=B8y?= <epost@anotheragency.no>
Date: Fri, 21 Sep 2018 07:13:16 +0200
Subject: [PATCH] Spelling: Ring ID -> RingID

Change-Id: Id821cda0c0a4c20376576c92a3aad01227f22fbf
Reviewed-by: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
---
 src/ringwelcomeview.cpp    | 4 ++--
 ui/accountmigrationview.ui | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/ui/accountmigrationview.ui b/ui/accountmigrationview.ui
index b9e78eff..bb93c471 100644
--- a/ui/accountmigrationview.ui
+++ b/ui/accountmigrationview.ui
@@ -123,7 +123,7 @@
                             <property name="visible">True</property>
                             <property name="can_focus">False</property>
                             <property name="halign">start</property>
-                            <property name="label" translatable="yes">Ring ID</property>
+                            <property name="label" translatable="yes">RingID</property>
                           </object>
                         </child>
                         <child>
diff --git a/src/ringwelcomeview.cpp b/src/ringwelcomeview.cpp
index bf18d654..4b1b989f 100644
--- a/src/ringwelcomeview.cpp
+++ b/src/ringwelcomeview.cpp
@@ -77,7 +77,7 @@ ring_welcome_update_view(RingWelcomeView* self) {
         return;
     }
 
     // Get registeredName, else the Ring Id
     gchar *ring_id = nullptr;
     if(! (*priv->accountInfo_)->registeredName.empty()){
         gtk_label_set_text(
@@ -201,7 +201,7 @@ ring_welcome_view_init(RingWelcomeView *self)
     gtk_widget_set_visible(priv->revealer_qrcode, FALSE);
 
     /* QR code button */
-    priv->button_qrcode = gtk_button_new_with_label(C_("Do not translate \"Ring ID\"", "Ring ID QR code"));
+    priv->button_qrcode = gtk_button_new_with_label(C_("Do not translate \"RingID\"", "RingID QR code"));
     gtk_widget_set_hexpand(priv->button_qrcode, FALSE);
     gtk_widget_set_size_request(priv->button_qrcode,10,10);
     g_signal_connect_swapped(priv->button_qrcode, "clicked", G_CALLBACK(switch_qrcode), self);
@@ -77,7 +77,7 @@ ring_welcome_update_view(RingWelcomeView* self) {
     }
 
-    // Get registeredName, else the Ring Id
+    // Get registeredName, else the RingID
     gchar *ring_id = nullptr;
     if(! (*priv->accountInfo_)->registeredName.empty()){
-- 
GitLab